#ifndef HelpText_h
#define HelpText_h

// $Id: HelpText.h,v 1.6 2013/04/29 18:27:10 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include <QObject>

//! help text
static const QString helpText[] =
{

    //_________________________________________________________
    QObject::tr( "Introduction" ),
    QObject::tr( "<h2>Introduction</h2>"
    "<p>Graphscan is a graphical tool that allows one to get the coordinate and errors corresponding to data points in a graph, relative to its horizontal and vertical axis.</p>"
    "<p>The process of acquiring the coordinates and errors consists of two steps:</p>"
    "<ul>"
    "<li>set the reference point needed to translate the absolute (<i>global</i>) mouse pointer coordinates into <i>local</i> coordinates, relative to the graph coordinates system;</li>"
    "<li>grab the data points (and errors) on the graph by means of the mouse, automatically converting the mouse pointer coordinates into local coordinates.</li>"
    "</ul>" ),

    //_________________________________________________________
    QObject::tr( "Quick Start" ),
    QObject::tr( "<h2>Quick Start</h2>"
    "<p>Below is the simplified list of steps needed to grab data from a graph:</p>"
    "<ul>"
    "<li>Open a graph (an image in any of the image formats that Qt recognizes). It is displayed in the main display.</li>"
    "<li>Select the three reference points, needed for setting up the global (mouse pointer position) to local (graph coordinates) transformation. Each point is selected by clicking at a given position (usually matching some finite value of the horizontal and vertical axis of the graph) with the left mouse button, and specifying in the resulting dialog the assiciated local coordinates, read on the graph axis. Once defined, the reference points' global position can be adjusted using either the keyboard arrows or drag-and-drop with the left mouse button. The local coordinates can be edited using the edit button in the reference point panel. The graph can be zoomed in in order to precisely adjust the global position of the reference points. Note that the reference points must not be aligned (that is: sit on the same line) neither in the global nor the local reference frame, for the global to local transformation to be valid.</li>"
    "<li>Grab data points from the graph by clicking with the midle mouse button on the graph, usually at the position of markers. Each grabbed points will appear in the markers list on the right of the main window, where they can be re-ordered or removed. New data points are first created without any error bars. Statistical and systematic error bars can be added by clicking with the right mouse button on one of the existing markers and selecting the corresponding action in the menu that pops up subsequently. One can either add errors manually, or add default errors, the value of such errors being set in the configuration dialog.</li>"
    "<li>Adjust the position of the markers and error bars by possibly zooming in the graph, and using either drag-and-drop, with left mouse button, or the keyboard arrows. For complex graphs with multiple data sets, one can grab the data sets independently by adding new marker sets in the markers list.</li>"
    "<li>Print the set of selected markers using either the print button in the markers list or the corresponding action in the tools menu.</li>"
    "</ul>" ),

    //_________________________________________________________
    QObject::tr( "Main Window" ),
    QObject::tr( "<h2>Main Window</h2>"
    "<p>The main window consists of the following parts: </p>"
    "<ul>"
    "<li>the menu bar, located at the top of the main window; </li>"
    "<li>the main display, located in the top-left part of the main window, below the menu bar;</li>"
    "<li>the reference point panel, located at the bottom of the main window;</li>"
    "<li>the markers list, located in the right part of the main window;</li>"
    "<li>the status bar, located at the bottom of the main window, below the reference point panel.</li>"
    "</ul>" ),

    //_________________________________________________________
    QObject::tr( "Main Menu" ),
    QObject::tr( "<h2>Main Menu</h2>"
    "<p>The main menu is located at the top of the main window. It allows to open a file (either for the first time of from a list of previously opened files); to save the current reference points and set of markers, to configure and to exit the application. It also contains some of the actions made available elsewhere, such as the possibility to add default error bars (both statistical and systematic) to the markers for which no errors have been defined yet, or to print the current set of markers. Finally it also provides access to this help.</p>" ),

    //_________________________________________________________
    QObject::tr( "Main Graphical Display" ),
    QObject::tr( "<h2>Main Graphical Display</h2>"
    "<p>The main display is located in the top-left part of the main window. It is where the current graph is represented from which the data points coordinates and errors are grabbed. Reference points, data points and error bars will be represented on this display with distinct appearance, and their respective position can be adjusted (<i>dragged</i>) using the mouse so that they match the underlying graph. Also visible on the main display is a notification area, which indicates what mouse actions are available to the user depending on the mouse pointer location.</p>"
    "<p>Interactions with the main display are performed using the mouse pointers and the keyboard arrows.</p>"
    "<p>The mouse pointer can be used to:</p>"
    "<ul>"
    "<li>Define reference points and markers (using left mouse button click);"
    "<li>Drag reference points, using left mouse button drag-and-drop, and change their <i>global</i> position, leaving the <i>local</i> position unchanged. All already defined data points (<i>markers</i>) are modified accordingly;</li>"
    "<li>Drag data points (<i>markers</i>), using left mouse button drag-and-drop, and change both their <i>global</i> coordinates (based on the position at which the dragged point is dropped) and thei <i>local</i> coordinates (using the existing reference points to set the global to local transformation);</li>"
    "<li>Drag reference points' error bars, using left mouse button drag-and-drop, and change both thei local and global coordinates</li>"
    "<li>Drag the display itself, using <Shift> and left mouse button drag-and-drop, for scrolling.</li>"
    "</ul>"
    "<p>The keyboard arrows can be used to move the selected reference point or data point, ajusting its global (and local) coordinates accordingly.</p>" ),

    //_________________________________________________________
    QObject::tr( "Reference Point Panel" ),
    QObject::tr( "<h2>Reference Point Panel</h2>"
    "<p>The reference point panel is located at the bottom of the main window. It displays the absolute (<i>global</i>) as well as the local position of the three reference points needed to setup the transformation from global to local coordinates. The global position is set by adding the point of the main display, using the mouse right button; the local position is set manually by the user, once the global position is selected. For each reference point, two buttons are also available:</p>"
    "<ul>"
    "<li>the first button is used to redefine the local coordinates associated to an already defined reference point;</li>"
    "<li>the second button is used to defined a reference point (both global and local coordinates), replacing the existing information if any.</li>"
    "</ul>"
    "<p>Clicking (left mouse button) on the text corresponding to a reference points selects it. The corresponding point is made visible on the main display, together with scanlines to make it easier to read its local coordinates on the graph axis, and can be moved around using the keyboard arrows. This results in changing its global coordinates, keeping the corresponding local coordinates unchanged and therefore re-calculating the global-to-local transformation. Clicking (left mouse button) anywhere else in the reference point panel clears the existing selection, if any.</p>"
    "<p>The reference point panel also contains an editable combo-box and two buttons used to zoom-in/zoom-out the graph displayed in the main window, as well as check-boxes to specify whether linear or log scale are used for the vertical and horizontal axis. </p>" ),

    //_________________________________________________________
    QObject::tr( "Markers List" ),
    QObject::tr( "<h2>Markers List</h2>"
    "<p>The markers list is located in the right part of the main window. It displays the current list of data points, grabbed from the main display, in a list. The list itself contains several columns that can be made visible/hidden by right-clicking on the list header and display the global and local coordinates of each data point together with its errors (both statistical and systematic).</p>"
    "<p>Markers in the list can be selected, moved up, moved down and removed, using buttons located on the right of the list. Additional actions are made available when right clicking on an element in the list.</p>"
    "<p>Graphscan allows one to define multiple <i>marker sets</i>, corresponding, for instance, to several curves shown on the graph. A combo-box is used to decide which marker set is shown in the list. New datasets can be added using the dedicated button located on the left of this combo-box. An existing data set can be removed entirely using the <i>remove</i> button located next to it. The current marker set is shown in the main display using distinct colors, whereas the other, inactive, marker sets appear in grey.</p>"
    "<p>The last button located on the right of the marker is used to <i>print</i> the active data set in a dedicated dialog, for use in external applications (e.g. a text editor). The content of the print dialog is detailed in its own section of this manual.</p>" ),

    //_________________________________________________________
    QObject::tr( "Error Edition Dialog" ),
    QObject::tr( "<h2>Error Edition Dialog</h2>"
    "<p>The error edition dialog is opened when selecting the edit errors action from either the main display or the markers list. It consists of three parts: </p>"
    "<ul>"
    "<li>the top part summarizes the local and global coordinates of the selected marker, for information;</li>"
    "<li>the middle part allows one to set the horizontal and vertical statistical errors on the marker;</li>"
    "<li>the bottom part allows one to set the horizontal and vertical systematic errors on the marker. At the moment, only vertical systematic errors are supported.</li>"
    "</ul>"
    "<p>These errors are represented using horizontal and vertical lines that cross at marker position, and which extend is proportional to the magnitude of the errors. They can be either symetric or asymetric. Also they can be defined as a fraction of the marker's position, when the <i>fractional</i> checkbox is selected.</p>" ),

    //_________________________________________________________
    QObject::tr( "Print Dialog" ),
    QObject::tr( "<h2>Print Dialog</h2>"
    "<p>The print dialog is opened when selecting the print action in the menu, or clicking the print button in the markers list. It offers the possibility to print one or several of the current markers' set into various formats suitable for further re-use. The list of available formats is shown inside a combo box. The available formats are:</p>"
    "<ul>"
    "<li>raw, to print the data points and errors in a raw format, suitable for text tables;</li>"
    "<li>LaTeX, to print the data points and errors in a LaTex table, suitable for inclusion in a LaTeX document;</li>"
    "<li>C, to print the data points in the form of C style arrays, suitable for re-use in a C/C++ program, such as a Root macri.</li>"
    "</ul>"
    "<p>The formated output is displayed in a text editor, from which it can be copied and re-used elsewhere.</p>"
    "<p>When multiple data sets are available for a given graph, a list of the data sets is shown on the left of the dialog, together with check boxes that allows one to select which datasets are printed in the editor.</p>" ),
    0
};

#endif
