#ifndef ImportImageDialog_h
#define ImportImageDialog_h

// $Id: ImportImageDialog.h,v 1.6 2014/02/10 14:11:29 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CustomDialog.h"
#include "File.h"

#include <QRadioButton>

class TextEditor;

class ImportImageDialog: public CustomDialog
{

    Q_OBJECT

    public:

    //! mode
    enum Mode
    {
        ReplaceCurrent = 1<<0,
        ReplaceExisting = 1<<1,
        Create = 1<<2,
        Any = ReplaceCurrent | ReplaceExisting | Create
    };

    Q_DECLARE_FLAGS( Modes, Mode )

    //! constructor
    ImportImageDialog( QWidget*, const File&, Modes mask = Any );

    //! destructor
    virtual ~ImportImageDialog( void )
    {}

    //! mode
    void setMode( Mode mode )
    {
        switch( mode )
        {
            case ReplaceCurrent: replaceCurrentCheckBox_->setChecked( true ); break;
            case ReplaceExisting: replaceExistingCheckBox_->setChecked( true ); break;
            case Create: createCheckBox_->setChecked( true ); break;
            default: break;
        }
    }

    //! mode
    Mode mode( void ) const
    {
        if( replaceCurrentCheckBox_->isChecked() ) return ReplaceCurrent;
        else if( replaceExistingCheckBox_->isChecked() ) return ReplaceExisting;
        else if( createCheckBox_->isChecked() ) return Create;
        else return Create;
    }

    private:

    //!@name checkboxes
    //@{
    QRadioButton* replaceCurrentCheckBox_;
    QRadioButton* replaceExistingCheckBox_;
    QRadioButton* createCheckBox_;
    //@}

};

Q_DECLARE_OPERATORS_FOR_FLAGS( ImportImageDialog::Modes )

#endif
