// $Id: Menu.cpp,v 1.24 2014/02/10 10:34:29 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Menu.h"
#include "Menu.moc"

#include "MainWindow.h"
#include "Application.h"
#include "Debug.h"
#include "DebugMenu.h"
#include "DefaultHelpText.h"
#include "DisplayWidget.h"
#include "DisplayWidget.h"
#include "HelpManager.h"
#include "HelpText.h"
#include "RecentImagesMenu.h"
#include "RefPointPanel.h"
#include "RefPointListWidget.h"
#include "Singleton.h"
#include "ZoomWidget.h"

//__________________________________________________
Menu::Menu( QWidget* parent ):
    QMenuBar( parent ),
    Counter( "Menu" )
{

    Debug::Throw( "Menu::Menu" );

    // generic menu
    QMenu *menu;

    Application& application( *Singleton::get().application<Application>() );
    MainWindow& mainWindow( *static_cast<MainWindow*>( window() ) );

    // create file menu
    menu = addMenu( tr( "File" ) );
    menu->addAction( &application.openAction() );

    // file menu
    recentImagesMenu_ = new RecentImagesMenu( this, application.recentImages() );
    connect( recentImagesMenu_, SIGNAL(fileSelected(ImageRecord)), &application, SLOT(open(ImageRecord)) );
    menu->addMenu( recentImagesMenu_ );

    // save and reload
    menu->addAction( &application.saveAction() );
    menu->addAction( &application.reloadAction() );

    menu->addSeparator();
    menu->addAction( &mainWindow.refPointListWidget().printAction() );
    menu->addAction( &mainWindow.refPointListWidget().printAllAction() );

    // import/export
    menu->addSeparator();
    menu->addAction( &application.importAction() );
    menu->addAction( &application.exportAction() );

    // exit
    menu->addSeparator();
    menu->addAction( &application.closeAction() );

    // create tools menu
    menu = addMenu( tr( "Edit" ) );
    menu->addAction( &mainWindow.undoAction() );
    menu->addAction( &mainWindow.redoAction() );
    menu->addSeparator();
    menu->addAction( &mainWindow.refPointPanel().zoomWidget().zoomInAction() );
    menu->addAction( &mainWindow.refPointPanel().zoomWidget().zoomOutAction() );
    menu->addSeparator();
    menu->addAction( &mainWindow.defaultErrorsAction() );
    menu->addAction( &mainWindow.defaultErrorsSystAction() );

    // create Settings menu
    menu = addMenu( tr( "Settings" ) );
    menu->addAction( &mainWindow.displayWidget().showRefPointsAction() );
    menu->addAction( &mainWindow.displayWidget().showInactivePointsAction() );
    menu->addAction( &mainWindow.displayWidget().showScanLinesAction() );

    menu->addSeparator();
    menu->addAction( &application.configurationAction() );
    menu->addAction( &mainWindow.refPointListWidget().refPointFormatAction() );

    // help manager
    Base::HelpManager* help( new Base::HelpManager( this ) );
    help->setWindowTitle( tr( "Graphscan Handbook" ) );
    help->install( helpText );
    help->install( Base::helpText, false );

    // create help menu
    menu = addMenu( tr( "Help" ) );
    menu->addAction( &help->displayAction() );
    menu->addSeparator();
    menu->addAction( &application.aboutAction() );
    menu->addAction( &application.aboutQtAction() );

    // debug menu
    menu->addSeparator();
    DebugMenu *debugMenu( new DebugMenu( menu ) );
    menu->addAction( debugMenu->menuAction() );
    debugMenu->menuAction()->setVisible( false );

}
