#ifndef RecentImagesMenu_h
#define RecentImagesMenu_h

// $Id: RecentImagesMenu.h,v 1.8 2013/10/25 09:39:36 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "Debug.h"
#include "ImageRecordList.h"

#include <QMenu>
#include <QHash>

/*!
\class   RecentImagesMenu
\brief   customized popup menu to open a previously opened file
*/
class RecentImagesMenu: public QMenu, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    RecentImagesMenu( QWidget*, ImageRecordList& );

    //! destructor
    virtual ~RecentImagesMenu( void );

    //! check if a file is in database, removes it if yes
    virtual void remove( const QString& file )
    { imageList_->remove( File( file ).expand() ); }

    //! check if a file is in database, adds it if not, select the file
    virtual void select( const QString& file )
    {
        File new_file( File( file ).expand() );
        emit fileSelected( imageList_->add( new_file ) );
    }

    //! open last valid file, returns true if any
    bool openLastValidFile( void );

    //! current file
    const ImageRecord& currentRecord( void ) const
    { return currentRecord_; }

    //! set current file
    void setCurrentRecord( const ImageRecord& );

    Q_SIGNALS:

    //! signal emited when a file is selected
    void fileSelected( ImageRecord );

    public Q_SLOTS:

    //! check if a file is in database, adds it if not
    virtual ImageRecord& add( const QString& file )
    { return imageList_->add( File( file ) ); }

    //! check if a file is in database, adds it if not
    virtual ImageRecord& add( File file )
    { return imageList_->add( file.expand() ); }

    private Q_SLOTS:

    //! update actions
    /*! this is trigger by the imageList valid file check completion */
    void _updateActions( void );

    //! remove unfound files from file list
    void _clean( void );

    //! open file
    void _open( QAction* );

    //! display files from internal list
    void _loadFiles( void );

    private:

    //! associated file list
    ImageRecordList* imageList_;

    //! store current file (to appear checked in list)
    ImageRecord currentRecord_;

    //! action group
    QActionGroup* actionGroup_;

    //! clean action
    QAction* cleanAction_;

    //! map actions to file recors
    typedef QHash<QAction*, ImageRecord> ActionMap;

    //! map actions to FileRecords
    ActionMap actions_;

};

#endif
