// $Id: RefPointDialog.cpp,v 1.10 2013/11/13 13:52:11 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "RefPointDialog.h"
#include "RefPointDialog.moc"

#include "GridLayout.h"
#include "LineEditor.h"

#include <QLabel>
#include <QDoubleValidator>

//_____________________________________________________________________
RefPointDialog::RefPointDialog( QWidget* parent ):
    CustomDialog( parent, OkButton|CancelButton|Separator )
{

    setWindowTitle( tr( "Edit Reference Point - Graphscan" ) );
    setOptionName( "REFPOINT_DIALOG" );

    QLabel* label( new QLabel( tr( "Specify the local coordinates of the reference point" ), this ) );
    mainLayout().addWidget( label );

    GridLayout* gridLayout( new GridLayout() );
    gridLayout->setMaxCount( 2 );
    mainLayout().addLayout( gridLayout );

    gridLayout->addWidget( label = new QLabel( "x: ", this ) );
    gridLayout->addWidget( xEditor_ = new LineEditor( this ) );

    label->setAlignment( Qt::AlignRight|Qt::AlignVCenter );
    xEditor_->setAlignment( Qt::AlignRight|Qt::AlignVCenter );
    xEditor_->setValidator( new QDoubleValidator() );

    gridLayout->addWidget( label = new QLabel( "y: ", this ) );
    gridLayout->addWidget( yEditor_ = new LineEditor( this ) );

    label->setAlignment( Qt::AlignRight|Qt::AlignVCenter );
    yEditor_->setAlignment( Qt::AlignRight|Qt::AlignVCenter );
    yEditor_->setValidator( new QDoubleValidator() );
    gridLayout->setColumnStretch( 1, 1 );

}

//_____________________________________________________________________
void RefPointDialog::setLocalPoint( QPointF position )
{
    xEditor_->setText( QString::number( position.x() ) );
    yEditor_->setText( QString::number( position.y() ) );

    xEditor_->selectAll();
    xEditor_->setFocus();

}

//_____________________________________________________________________
QPointF RefPointDialog::localPoint( void ) const
{ return QPointF( xEditor_->text().toDouble(), yEditor_->text().toDouble() ); }
