#ifndef RefPointWidget_h
#define RefPointWidget_h

// $Id: RefPointWidget.h,v 1.18 2013/10/25 09:39:36 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "CustomToolBar.h"
#include "RefPoint.h"

#include <QLabel>
#include <QAction>
#include <QList>

class RefPointWidget: public QObject, public Counter
{

    Q_OBJECT

    public:

    //! shortcut
    typedef QList<RefPointWidget*> List;

    //! constructor
    RefPointWidget( QWidget* );

    //! destructor
    virtual ~RefPointWidget( void )
    {}

    //! set hovered
    bool setHovered( bool );

    //! hovered
    bool isHovered( void ) const
    { return hovered_; }

    //! set selected
    bool setSelected( bool );

    //! true if selected
    bool isSelected( void ) const
    { return selected_; }

    //!@name child widgets
    //@{
    //! name
    QLabel& nameLabel( void ) const
    { return *nameLabel_; }

    //! global position
    QLabel& globalPointLabel( void ) const
    { return *globalPointLabel_; }

    //! local position
    QLabel& localPointLabel( void ) const
    { return *localPointLabel_; }

    //@}

    //! toolbar
    QToolBar& toolbar( void ) const
    { return *toolbar_; }

    //!@name actions
    //@{

    //! edit
    QAction& editAction( void ) const
    { return *editAction_; }

    //! clear
    QAction& clearAction( void ) const
    { return *clearAction_; }

    //@}

    //! true if argument is child of this
    bool hasChild( const QObject* object ) const
    {
        return
            object == &nameLabel() ||
            object == &globalPointLabel() ||
            object == &localPointLabel();
    }

    //@}

    //!@name reference point
    //@{

    const RefPoint& point( void ) const
    { return point_; }

    void setPoint( const RefPoint& );

    //! return true if valid
    bool isValid( void ) const
    { return !( globalPointLabel().text().isEmpty() || localPointLabel().text().isEmpty() ); }

    //! clear
    void clear( void );

    //@}

    Q_SIGNALS:

    // emitted when modified
    void modified( void );

    private:

    //! true if initialized
    bool initialized_;

    //! true if hovered
    bool hovered_;

    //! true if selected
    bool selected_;

    //! name label
    QLabel* nameLabel_;

    //! point label (global)
    QLabel* globalPointLabel_;

    //! Point label (local)
    QLabel* localPointLabel_;

    //! toolbar
    CustomToolBar* toolbar_;

    //!edit action
    QAction* editAction_;

    //! clear action
    QAction* clearAction_;

    //! associated reference point
    RefPoint point_;

};

#endif
